<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Feed
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Feed
 *
 * @category   Phire
 * @package    Phire_Feed
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Feed
{

    /**
     * Feed object
     * @var Moc10_Feed_Writer
     */
    protected $_feed = null;

    /**
     * Feed type
     * @var string
     */
    protected $_type = null;

    /**
     * Feed limit
     * @var string
     */
    protected $_limit = null;

    /**
     * Feed header
     * @var array
     */
    protected $_header = array();

    /**
     * Feed items
     * @var array
     */
    protected $_items = array();

    /**
     * Constructor
     *
     * Instantiate the feed object.
     *
     * @return void
     */
    public function __construct()
    {

        // Get system information.
        $sys = new Phire_Table_Config();
        $last_build_date = ($sys->settings['updated_on'] != '0000-00-00 00:00:00') ? date('D, j M Y H:i:s O', strtotime($sys->settings['updated_on'])) : date('D, j M Y H:i:s O', strtotime($sys->settings['installed_on']));

        // Get site information.
        $site = new Phire_Table_Sites();
        $site->findBy('site_domain', $_SERVER['HTTP_HOST']);

        $this->_type = $site->feed_type;
        $this->_limit = ($site->feed_limit > 0) ? " LIMIT " . $site->feed_limit : '';

        if ($this->_type == 'RSS') {

            $this->_header = array('title' => (string)Moc10_String::setString($site->default_title)->strip()->html()->replace('&', '<![CDATA[&]]>'),
                                   'link' => 'http://' . $_SERVER['HTTP_HOST'],
                                   'description' => (string)Moc10_String::setString($site->default_desc)->strip()->html()->replace('&', '<![CDATA[&]]>'),
                                   'language' => 'en',
                                   'lastBuildDate' => $last_build_date,
                                   'generator' => 'http://www.phirecms.org/',
                                   'managingEditor' => (string)Moc10_String::setString($site->default_author)->strip()->html()->replace('&', '<![CDATA[&]]>'));
        } else {

            $this->_header = array('title' => (string)Moc10_String::setString($site->default_title)->strip()->html()->replace('&', '<![CDATA[&]]>'),
                                   'subtitle' => (string)Moc10_String::setString($site->default_desc)->strip()->html()->replace('&', '<![CDATA[&]]>'),
                                   'link' => 'http://' . $_SERVER['HTTP_HOST'],
                                   'language' => 'en',
                                   'updated' => $last_build_date,
                                   'generator' => 'http://www.phirecms.org/',
                                   'author' => (string)Moc10_String::setString($site->default_author)->strip()->html()->replace('&', '<![CDATA[&]]>'));

        }

        $this->_items = array();

        // Get the pages in the RSS feed.
        $pages = new Phire_Table_Pages();
        $pages->execute("SELECT * FROM " . DB_PREFIX . "pages WHERE site_id = '" . $site->site_id . "' AND feed = 'Yes' AND published = 'Yes' ORDER BY created DESC" . $this->_limit);

        if (isset($pages->rows[0])) {

            // Parse each RSS feed item, set it into the template and print it.
            foreach($pages->rows as $page) {

                $page_title = Moc10_String::setString($page->page_title)->striptags();
                $page_author = Moc10_String::setString($page->page_author);
                $pub_date = Moc10_String::setString($page->created)->date('D, j M Y H:i:s O');

                // Create page summary, stripping away JS tags and content, normal HTML tags and white space.
                if ($page->page_content != '') {
                    $page_content = Moc10_String::setString($page->page_content)->replace('[{page_sub_title}]', $page->page_title)->preg('/<script(.*?)<\/script>/si', '')->striptags()->preg('/\[\{(.?)*\}\]/', '')->preg('/\s\s+/', '')->strip();
                    if ($page_content->length() > 300) {
                        $page_content->sub(0, 300);
                    }
                    if ($page_content != '') {
                        $page_content .= '...';
                    }
                } else {
                    $page_content = '';
                }

                if ($this->_type == 'RSS') {
                    $this->_items[] = array('title' => (string)$page_title->strip()->html()->replace('&', '<![CDATA[&]]>')->replace("<![CDATA[&]]>#039;", "'"),
                                            'link' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . $page->page_url,
                                            'comments' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . $page->page_url . '#comments',
                                            'author' => (string)$page_author->strip()->html()->replace('&', '<![CDATA[&]]>'),
                                            'pubDate' => (string)$pub_date,
                                            'description' => '<![CDATA[' . (string)$page_content . ']]>');
                } else {
                    $this->_items[] = array('title' => (string)$page_title->strip()->html()->replace('&', '<![CDATA[&]]>')->replace("<![CDATA[&]]>#039;", "'"),
                                            'link' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . $page->page_url,
                                            'comments' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . $page->page_url . '#comments',
                                            'author' => (string)$page_author->strip()->html()->replace('&', '<![CDATA[&]]>'),
                                            'updated' => (string)$pub_date,
                                            'summary' => '<![CDATA[' . (string)$page_content . ']]>');
                }

            }

        }

        $this->_feed = new Moc10_Feed_Writer($this->_header, $this->_items, strtoupper($this->_type));

    }

    /**
     * Render the feed.
     *
     * @return void
     */
    public function render()
    {

        $this->_feed->render();

    }

}
