<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_EditImage
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_EditImage extends Moc10_Form
{

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => null,
                                   'section_id' => null,
                                   'image_name' => null,
                                   'image_title' => null,
                                   'image_caption' => null,
                                   'image_updated' => null,
                                   'current_image_name' => null,
                                   'mobile' => null,
                                   'image_id' => 0);

    /**
     * Initialization method for the edit image form.
     *
     * @param  array $post
     * @param  string $img_nme
     * @return void
     */
    public function init($post = null, $img_nme = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post, $img_nme);
        $this->_setTemplates();

        $this->setAttributes('id', 'editImageForm');
        $this->setAttributes('enctype', 'multipart/form-data');

        // Get sections.
        $sects = new Phire_Table_Sections();
        $sects->findAll('section_id ASC', 'site_id', $this->_postFields['site_id']);
        $sectAry = array('0' => '(' . $lang->__('None') . ')');
        if (isset($sects->rows[0])) {
            foreach ($sects->rows as $sect) {
                $sectAry[$sect->section_id] = $sect->section_title;
            }
        }

        // Create the 'section_id' form element.
        $section_id = new Moc10_Form_Element_Select('section_id', $sectAry, $this->_postFields['section_id']);
        $section_id->setLabel($lang->__('Section:'));

        $brws = new Moc10_Session_Browser();
        $fileClass = ($brws->browser == 'MSIE') ? 'fileInputIE' : 'fileInput';

        // Create the 'image_name' form element.
        $image_name = new Moc10_Form_Element('file', 'image_name', null);
        $image_name->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Replace?') : $lang->__('Replace Current Image?')));
        $image_name->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '35'));
        $image_name->setAttributes('class', $fileClass);

        // Create the 'image_title' form element.
        $image_title = new Moc10_Form_Element('text', 'image_title', $this->_postFields['image_title']);
        $image_title->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Title:') : $lang->__('Image Title:')));
        $image_title->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '45'));

        // Create the 'image_caption' form element.
        $image_caption = new Moc10_Form_Element('text', 'image_caption', $this->_postFields['image_caption']);
        $image_caption->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Caption:') : $lang->__('Image Caption:')));
        $image_caption->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '70'));

        // Create the 'current_image_name' form element.
        $current_image_name = new Moc10_Form_Element('hidden', 'current_image_name', $this->_postFields['image_name']);

        // Create the 'image_id' form element.
        $image_id = new Moc10_Form_Element('hidden', 'image_id', $this->_postFields['image_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
            $sess = Moc10_Session::getInstance();
            $submit->setAttributes('class', 'submitBtn');
            $site_id = new Moc10_Form_Element('hidden', 'site_id', $sess->cur_site_id);
            $this->setTemplate($this->_templates['mobile']);
        } else {
            $site_id = new Moc10_Form_Element_Select('site_id', Phire_Sites::getAllowedSites(), $this->_postFields['site_id']);
            $site_id->setLabel('Site:');
            $submit->setAttributes('class', 'submitBtn');
            $site_id->setAttributes('onchange', "xmlhttp.getRequest('../core/process/check.section.php?site_id=' + this.value, editImageFrm.changeSection); return false;");
            $this->setTemplate($this->_templates['main']);
        }

        // Add the form element objects to the form.
        $this->addElements(array($site_id, $section_id, $image_name, $image_title, $image_caption, $submit, $current_image_name, $image_id));

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $last = $lang->__('Last Updated:');
        $back = $lang->__('Back');
        $donot_wrap = wordwrap($lang->__('Once you click save, DO NOT leave the page until the images have finished processing.'), 80, "<br />");
        $donot = $lang->__('Once you click save, DO NOT leave the page until the images have finished processing.');
        $cancel = $lang->__('CANCEL');

        if (!is_null($this->_postFields['image_updated'])) {
            $last_update = ($this->_postFields['image_updated'] != '0000-00-00 00:00:00') ? '<strong>' . $last . '</strong> ' . date('l, M j, Y g:i A', strtotime($this->_postFields['image_updated'])) : '<strong>Last Updated:</strong> Never';
            $dateStamp = "<span style=\"padding: 0 15px 0 15px;\">" . $last_update . "</span>";
        } else {
            $dateStamp = '&nbsp;';
        }

        $site = new Phire_Table_Sites();
        $site->getSite($this->_postFields['site_id']);
        $lgDomain = 'http://' . $site->site_domain . BASE_PATH . CONTENT_PATH . '/assets/images/large/';

        $size = null;
        $img = new Moc10_Image($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $this->_postFields['image_name']);

        if ($img->size < 1000) {
            $size = '< 1 KB';
        } else if (($img->size >= 1000) && ($img->size < 1000000)) {
            $size = round(($img->size / 1000), 1) . ' KB';
        } else if ($img->size >= 1000000) {
            $size = round(($img->size / 1000000), 2) . ' MB';
        } else {
            $size = $img->size;
        }

        if (isset($img->width) && isset($img->height)) {
            $size .= '<br />(' . $img->width . ' x ' . $img->height . ')';
        }

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './images.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        {$dateStamp}
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td colspan="4" class="textRight">
                                    [{site_id_label}]
                                    [{site_id}]
                                    <span style="padding: 0 10px 0 10px;"> </span>
                                    [{section_id_label}]
                                    <span id="sectionDiv">
                                        [{section_id}]
                                    </span>
                                </td>
                            </tr>
                            <tr>
                                <td style="text-align: center;">
                                    <strong>View</strong>
                                </td>
                                <td>
                                    [{image_name_label}]
                                </td>
                                <td>
                                    [{image_title_label}]
                                </td>
                                <td>
                                    [{image_caption_label}]
                                </td>
                            </tr>
                            <tr>
                                <td style="width: 80px; vertical-align: top; text-align: center;">
                                    <a href="{$lgDomain}{$this->_postFields['image_name']}" title="View {$this->_postFields['image_name']}"><img src="{$lgDomain}{$this->_postFields['image_name']}" width="50%" alt="View {$this->_postFields['image_name']}" /></a>
                                </td>
                                <td style="vertical-align: top;">
                                    [{image_name}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{image_title}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{image_caption}]
                                </td>
                            </tr>
                            <tr>
                                <td style="vertical-align: top; text-align: center;">
                                    <span style="font-size: 0.8em;">{$size}</span>
                                </td>
                                <td colspan="3">
                                    <strong style="float: left; color: #f00;">{$donot_wrap}</strong><a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/edit.image.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] [{image_id}] [{current_image_name}] {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            editImageFormInit();
                            var xmlhttp = new JaxXmlHttp();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./images.php">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        {$dateStamp}
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td class="textRight">
                                    [{section_id_label}]
                                </td>
                                <td>
                                    [{section_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{image_name_label}]
                                </td>
                                <td id="imageNameTD" style="vertical-align: top;">
                                    [{image_name}]<br />
                                    <a href="{$lgDomain}{$this->_postFields['image_name']}" title="View {$this->_postFields['image_name']}"><img src="{$lgDomain}{$this->_postFields['image_name']}" width="120" alt="View {$this->_postFields['image_name']}" /></a><br />
                                    <span style="font-size: 0.8em;">{$size}</span>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{image_title_label}]
                                </td>
                                <td id="imageTitleTD" style="vertical-align: top;">
                                    [{image_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{image_caption_label}]
                                </td>
                                <td id="imageCaptionTD" style="vertical-align: top;">
                                    [{image_caption}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <strong style="color: #f00;">{$donot}</strong><br /><br />
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/edit.image.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] {$mobile} [{site_id}] [{current_image_name}] [{image_id}]
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @param  string $img_nme
     * @return void
     */
    protected function _setFields($post = null, $img_nme = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['image_id']) && ($post['image_id'] != 0)) {

                $image = new Phire_Table_Images();
                $image->findById($post['image_id']);

                $this->_postFields['site_id'] = $image->site_id;
                $this->_postFields['section_id'] = $image->section_id;
                $this->_postFields['image_name'] = $image->image_name;
                $this->_postFields['image_title'] = (string)Moc10_String::setString($image->image_title)->strip()->html();
                $this->_postFields['image_caption'] = (string)Moc10_String::setString($image->image_caption)->strip()->html();
                $this->_postFields['image_updated'] = $image->image_updated;
                $this->_postFields['current_image_name'] = $image->image_name;
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['mobile'] = (isset($post['mobile'])) ? $post['mobile'] : null;
                $this->_postFields['image_id'] = $image->image_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
                $this->_postFields['image_name'] = $img_nme;
            }
        }

    }

}
