<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Feed
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Feed extends Moc10_Form
{

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => 0,
                                   'feed_title' => null,
                                   'feed_url' => null,
                                   'feed_template' => null,
                                   'list_limit' => null,
                                   'mobile' => null,
                                   'feed_id' => 0);

    /**
     * Initialization method for the feed form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'addFeedForm');

        // Create the 'feed_title' form element.
        $feed_title = new Moc10_Form_Element('text', 'feed_title', $this->_postFields['feed_title']);
        $feed_title->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '100'));
        $feed_title->setRequired(true);
        $feed_title->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Title:') : $lang->__('Feed Title:')));

        // Create the 'feed_url' form element.
        $feed_url = new Moc10_Form_Element('text', 'feed_url', $this->_postFields['feed_url']);
        $feed_url->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '25' : '100'));
        $feed_url->setRequired(true);
        $feed_url->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('URL:') : $lang->__('Feed URL:')));

        // Create the 'list_limit' form element.
        $list_limit = new Moc10_Form_Element('text', 'list_limit', $this->_postFields['list_limit']);
        $list_limit->addValidator('Num');
        $list_limit->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '3:' : '5'));
        $list_limit->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Limit:') : $lang->__('List Limit:')));

        // Create the 'feed_template' form element.
        $feed_template = new Moc10_Form_Element_Textarea('feed_template', $this->_postFields['feed_template']);
        $feed_template->setAttributes('cols', ((!is_null($this->_postFields['mobile'])) ? '30' : '100'));
        $feed_template->setAttributes('rows', ((!is_null($this->_postFields['mobile'])) ? '4' : '8'));
        $feed_template->setAttributes('spellcheck', 'false');
        $feed_template->setAttributes('wrap', 'off');
        $feed_template->setRequired(true);
        $feed_template->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Template:') : $lang->__('Feed Template:')));

        // Create the 'feed_id' form element.
        $feed_id = new Moc10_Form_Element('hidden', 'feed_id', $this->_postFields['feed_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
            $sess = Moc10_Session::getInstance();
            $submit->setAttributes('class', 'submitBtn');
            $site_id = new Moc10_Form_Element('hidden', 'site_id', $sess->cur_site_id);
            $this->setTemplate($this->_templates['mobile']);
        } else {
            $this->setAttributes('onsubmit', "return addFeedFrm.validate();");
            $site_id = new Moc10_Form_Element_Select('site_id', Phire_Sites::getAllowedSites(), $this->_postFields['site_id']);
            $site_id->setLabel($lang->__('Add to Site:'));
            $submit->setAttributes('class', 'submitBtn');
            $feed_title->setAttributes('style', 'width: 530px;');
            $feed_url->setAttributes('style', 'width: 530px;');
            $feed_template->setAttributes('style', 'width: 530px;');
            $this->setTemplate($this->_templates['main']);
        }

        // Add the form element objects to the form.
        $this->addElements(array($site_id, $feed_title, $feed_url, $feed_template, $list_limit, $submit, $feed_id));

    }

    /**
     * Method to save the feed data.
     *
     * @return void
     */
    public function saveData()
    {

        if ($this->_postFields['feed_id'] != 0) {

            $feed = new Phire_Table_Feeds();
            $feed->findById($this->_postFields['feed_id']);

            $feed->site_id = $this->_postFields['site_id'];
            $feed->feed_title = $this->_postFields['feed_title'];
            $feed->feed_url = $this->_postFields['feed_url'];
            $feed->feed_template = $this->_postFields['feed_template'];
            $feed->list_limit = ($this->_postFields['list_limit'] != '') ? $this->_postFields['list_limit'] : 0;

        } else {

            $fields = array('site_id' => $this->_postFields['site_id'],
                            'feed_title' => $this->_postFields['feed_title'],
                            'feed_url' => $this->_postFields['feed_url'],
                            'feed_template' => $this->_postFields['feed_template'],
                            'list_limit' => (($this->_postFields['list_limit'] != '') ? $this->_postFields['list_limit'] : 0));
            $feed = new Phire_Table_Feeds($fields);
        }

        $feed->save();

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['feed_id']) && ($post['feed_id'] != 0)) {

                $feed = new Phire_Table_Feeds();
                $feed->findById($post['feed_id']);

                $this->_postFields['site_id'] = $feed->site_id;
                $this->_postFields['feed_title'] = (string)Moc10_String::setString($feed->feed_title)->strip()->html();
                $this->_postFields['feed_url'] = (string)Moc10_String::setString($feed->feed_url)->strip()->html();
                $this->_postFields['feed_template'] = (string)Moc10_String::setString($feed->feed_template)->strip()->html();
                $this->_postFields['list_limit'] = (string)Moc10_String::setString($feed->list_limit)->strip()->html();
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['mobile'] = (isset($post['mobile'])) ? $post['mobile'] : null;
                $this->_postFields['feed_id'] = $feed->feed_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $back = $lang->__('Back');
        $blue = $lang->__('Blue fields are required.');
        $zero = $lang->__('0 for no limit');
        $cancel = $lang->__('CANCEL');

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './feeds.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td class="textRight">
                                    <h4 style="float: left;">{$blue}</h4>
                                    [{site_id_label}]
                                    [{site_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{feed_title_label}]
                                </td>
                                <td>
                                    [{feed_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{feed_url_label}]
                                </td>
                                <td>
                                    [{feed_url}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{list_limit_label}]
                                </td>
                                <td>
                                    [{list_limit}] <em>({$zero})</em>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{feed_template_label}]
                                </td>
                                <td>
                                    [{feed_template}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/add.feed.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] [{feed_id}] {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addFeedFormInit();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./feeds.php">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{feed_title_label}]
                                </td>
                                <td>
                                    [{feed_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{feed_url_label}]
                                </td>
                                <td>
                                    [{feed_url}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{list_limit_label}]
                                </td>
                                <td>
                                    [{list_limit}] <em>({$zero})</em>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{feed_template_label}]
                                </td>
                                <td>
                                    [{feed_template}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/add.feed.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] [{site_id}] [{feed_id}] {$mobile}
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
