<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_SelectSite
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_SelectSite extends Moc10_Form
{

    /**
     * Initialization method for the select site form.
     *
     * @param  string|int $ste_id
     * @return void
     */
    public function init($ste_id = 0)
    {

        $lang = new Phire_Language();

        $this->setAttributes('id', 'selectSiteForm');

        // Create the 'site_id' form element.
        $site_id = new Moc10_Form_Element_Select('site_id', Phire_Sites::getAllowedSites(), $ste_id);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SELECT'));
        $submit->setAttributes('class', 'submitBtn');

        $sel = $lang->__('Select a Site.');
        $pls_sel = $lang->__('Please select the site you wish to work on from your mobile device. You can always switch later.');

        // Define the form template.
        $tmpl = <<<FORMTEMP
            <table id="selectSiteTable" cellspacing="0" cellpadding="0">
                <tr>
                    <td>
                        <h2 class="blueHeader">{$sel}</h2>
                    </td>
                </tr>
                <tr>
                    <td>
                        <span>{$pls_sel}</span>
                    </td>
                </tr>
                <tr>
                    <td>
                        [{site_id}]
                    </td>
                </tr>
                <tr>
                    <td>
                        [{submit}]
                    </td>
                </tr>
            </table>
FORMTEMP;

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($tmpl);
        $this->addElements(array($site_id, $submit));

    }

}
