<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Parser_Section
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Parser_Section
{

    /**
     * Section matches
     * @var array
     */
    protected $_matches = array();

    /**
     * Section RegEx
     * @var string
     */
    protected $_regex = '/\[\{section_\d*\}\]/';

    /**
     * Content to evaluate
     * @var string
     */
    protected $_content = null;

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Constructor
     *
     * Instantiate the section parser object.
     *
     * @param  string $content
     * @param  string $url
     * @return void
     */
    public function __construct($content, $url = null)
    {

        // Perform a preg_match_all to look for any section tags within the content, then parse the content.
        $this->_content = $content;
        preg_match_all($this->_regex, $this->_content, $this->_matches);
        $this->_parse();

    }

    /**
     * Static method to instantiate the section parser object
     * and return the parsed string.
     *
     * @param  string $cont
     * @param  string $u
     * @return Phire_Parser_Section
     */
    public static function init($cont, $u = null)
    {

        return new self($cont, $u);

    }

    /**
     * Set content within the content property.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_content = str_replace($subject, $replace, $this->_content);

    }

    /**
     * Get content within the content property.
     *
     * @return string
     */
    public function getContent()
    {

        return $this->_content;

    }

    /**
     * Renders any section elements within the content.
     *
     * @return void
     */
    protected function _parse()
    {

        $lang = new Phire_Language();

        // If section tag elements are found, format and set in content.
        if (isset($this->_matches[0][0])) {

            foreach ($this->_matches[0] as $value) {

                $sess = Moc10_Session::getInstance();

                $section_format = '';
                $section_count = 0;

                $sid = str_replace('[{section_', '', $value);
                $sid = str_replace('}]', '', $sid);

                $section = new Phire_Table_Sections();
                $section->findById($sid);

                $site = new Phire_Table_Sites();
                $site->getSite();

                $date_format = $site->default_date_format;
                $time_format = ($site->default_time_format != '') ? ' ' . $site->default_time_format : '';

                if (isset($section->section_id) && ($section->site_id == $site->site_id)) {

                    try {

                        $limit = ($section->short_limit > 0) ? $section->short_limit : null;
                        $section_format .= ($section->short_template_container != 'None') ? str_replace(">", " id=\"sectionShort{$section->section_id}\">\n", $section->short_template_container) : '';

                        $sort = explode('|', $section->sort_order);
                        if (stripos($sort[1], 'Today') !== false) {
                            $sortOrder = substr($sort[1], 0, strpos($sort[1], ' '));
                            $dateLimit = null;
                            if (stripos($sort[1], '>=') !== false) {
                                $dateLimit = ' AND [{date_marker}] >= CURDATE()';
                            } else {
                                $dateLimit = ' AND [{date_marker}] <= CURDATE()';
                            }
                        } else {
                            $sortOrder = $sort[1];
                            $dateLimit = null;
                        }
                        // Set sort order.
                        switch ($sort[0]) {
                            case 'ID':
                                if ($sortOrder != 'RAND()') {
                                    $sort_page = 'page_id ' . $sortOrder;
                                    $sort_file = 'file_id ' . $sortOrder;
                                    $sort_image = 'image_id ' . $sortOrder;
                                    $sort_event = 'event_id ' . $sortOrder;
                                } else {
                                    $sort_page = $sortOrder;
                                    $sort_file = $sortOrder;
                                    $sort_image = $sortOrder;
                                    $sort_event = $sortOrder;
                                }
                                break;

                            case 'Title':
                                if ($sortOrder != 'RAND()') {
                                    $sort_page = 'page_title ' . $sortOrder;
                                    $sort_file = 'file_title ' . $sortOrder;
                                    $sort_image = 'image_title ' . $sortOrder;
                                    $sort_event = 'event_title ' . $sortOrder;
                                } else {
                                    $sort_page = $sortOrder;
                                    $sort_file = $sortOrder;
                                    $sort_image = $sortOrder;
                                    $sort_event = $sortOrder;
                                }
                                break;

                            case 'Date':
                                if ($sortOrder != 'RAND()') {
                                    $sort_page = 'created ' . $sortOrder;
                                    $sort_file = 'file_updated ' . $sortOrder;
                                    $sort_image = 'image_updated ' . $sortOrder;
                                    $sort_event = 'event_start_date, event_start_time ' . $sortOrder;
                                } else {
                                    $sort_page = $sortOrder;
                                    $sort_file = $sortOrder;
                                    $sort_image = $sortOrder;
                                    $sort_event = $sortOrder;
                                }
                                break;

                        }

                        // Get any pages within the section.
                        if (isset($sess->member_id)) {
                            $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE section_id = '{$section->section_id}' AND published = 'Yes'" . str_replace('[{date_marker}]', 'created', $dateLimit) . " ORDER BY " . $sort_page;
                        } else {
                            $sql = "SELECT * FROM " . DB_PREFIX . "pages WHERE section_id = '{$section->section_id}' AND published = 'Yes' AND page_access = 'Public'" . str_replace('[{date_marker}]', 'created', $dateLimit) . " ORDER BY " . $sort_page;
                        }
                        $sql .= ($limit != 0) ? " LIMIT {$limit}" : '';
                        $pages = new Phire_Table_Pages();
                        $pages->execute($sql);

                        // Get any files within the section.
                        $files = new Phire_Table_Files();
                        $files->findAll($sort_file, 'section_id', $section->section_id, $limit);

                        // Get any images within the section.
                        $images = new Phire_Table_Images();
                        $images->findAll($sort_image, 'section_id', $section->section_id, $limit);

                        // Get any events within the section.
                        if (isset($sess->member_id)) {
                            $sql = "SELECT * FROM " . DB_PREFIX . "events WHERE section_id = '{$section->section_id}'" . str_replace('[{date_marker}]', 'event_start_date', $dateLimit) . " ORDER BY " . $sort_event;
                        } else {
                            $sql = "SELECT * FROM " . DB_PREFIX . "events WHERE section_id = '{$section->section_id}' AND event_access = 'Public'" . str_replace('[{date_marker}]', 'event_start_date', $dateLimit) . " ORDER BY " . $sort_event;
                        }
                        $sql .= ($limit != 0) ? " LIMIT {$limit}" : '';
                        $events = new Phire_Table_Events();
                        $events->execute($sql);

                        // If pages found, format and set in content.
                        if (isset($pages->rows[0])) {
                            $section_count++;
                            $item_count = 0;
                            foreach ($pages->rows as $val) {
                                $item_count++;
                                $tmpl = $section->short_template;

                                $matches = array();
                                preg_match_all('/\[\{page_content_\d*\}\]/', $tmpl, $matches);

                                if (isset($matches[0][0])) {
                                    foreach ($matches[0] as $v) {
                                        $sub = str_replace('[{page_content_', '', $v);
                                        $sub = str_replace('}]', '', $sub);
                                        $stripped_content = preg_replace('/\[\{(.*?)\}\]/', '', $val['page_content']);
                                        if (strlen($val['page_content']) < $sub) {
                                            $str = $val['page_content'];
                                        } else {
                                            $str = substr(trim(strip_tags($stripped_content)), 0, $sub);
                                            //if (strlen($stripped_content) > $sub) {
                                            //    //echo $stripped_content . '<br /><br />' . PHP_EOL;
                                            //    $str = (string)Moc10_String::setString($stripped_content)->striptags()->trim()->sub(0, $sub);
                                            //} else if (strlen($stripped_content) > 0) {
                                            //    //echo 456 . '<br />' . PHP_EOL;
                                            //    $str = (string)Moc10_String::setString($stripped_content)->striptags()->trim();
                                            //} else {
                                            //    //echo 789 . '<br />' . PHP_EOL;
                                            //    $str = '...';
                                            //}
                                        }
                                        $tmpl = str_replace($v, $str . '...', $tmpl);
                                    }
                                }

                                $tmpl = str_replace('[{page_url}]', BASE_PATH. $val['page_url'], $tmpl);
                                $tmpl = str_replace('[{page_title}]', $val['page_title'], $tmpl);
                                $tmpl = str_replace('[{page_sub_title}]', $val['page_title'], $tmpl);
                                $tmpl = str_replace('[{page_author}]', $val['page_author'], $tmpl);
                                $tmpl = str_replace('[{page_keywords}]', $val['page_keywords'], $tmpl);
                                $tmpl = str_replace('[{page_desc}]', $val['page_desc'], $tmpl);
                                $tmpl = str_replace('[{page_created}]', (string)Moc10_String::setString($val['created'])->date($date_format . $time_format), $tmpl);
                                $tmpl = str_replace('[{page_updated}]', (string)Moc10_String::setString($val['updated'])->date($date_format . $time_format), $tmpl);
                                $tmpl = str_replace('[{site_domain}]', $site->site_domain, $tmpl);
                                $tmpl = str_replace('[{base_path}]', BASE_PATH, $tmpl);
                                $tmpl = str_replace('[{sys_path}]', SYS_PATH, $tmpl);
                                $tmpl = str_replace('[{content_path}]', CONTENT_PATH, $tmpl);
                                $tmpl = str_replace('[{count}]', $item_count, $tmpl);

                                $section_format .= $tmpl;
                            }
                        }

                        // If files found, format and set in content.
                        if (isset($files->rows[0])) {
                            $section_count++;
                            $item_count = 0;
                            foreach ($files->rows as $val) {
                                $item_count++;
                                $tmpl = $section->short_template;
                                $tmpl = str_replace('[{file_name}]', $val['file_name'], $tmpl);
                                $tmpl = str_replace('[{file_title}]', $val['file_title'], $tmpl);
                                $tmpl = str_replace('[{file_desc}]', $val['file_desc'], $tmpl);
                                $tmpl = str_replace('[{file_updated}]', (string)Moc10_String::setString($val['file_updated'])->date($date_format . $time_format), $tmpl);
                                if ((stripos($val['file_name'], '.jpg') !== false) || (stripos($val['file_name'], '.jpeg') !== false) || (stripos($val['file_name'], '.jpe') !== false) || (stripos($val['file_name'], '.gif') !== false) || (stripos($val['file_name'], '.png') !== false)) {
                                    $fle = new Moc10_Image($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $val['file_name']);
                                    $tmpl = str_replace('[{width}]', $fle->width, $tmpl);
                                    $tmpl = str_replace('[{height}]', $fle->height, $tmpl);
                                } else {
                                    $tmpl = str_replace('[{width}]', '', $tmpl);
                                    $tmpl = str_replace('[{height}]', '', $tmpl);
                                }
                                $tmpl = str_replace('[{site_domain}]', $site->site_domain, $tmpl);
                                $tmpl = str_replace('[{base_path}]', BASE_PATH, $tmpl);
                                $tmpl = str_replace('[{sys_path}]', SYS_PATH, $tmpl);
                                $tmpl = str_replace('[{content_path}]', CONTENT_PATH, $tmpl);
                                $tmpl = str_replace('[{count}]', $item_count, $tmpl);
                                $section_format .= $tmpl;
                            }
                        }

                        // If images found, format and set in content.
                        if (isset($images->rows[0])) {
                            $section_count++;
                            $item_count = 0;
                            foreach ($images->rows as $val) {
                                $item_count++;
                                $tmpl = $section->short_template;
                                $lg_width = null;
                                $lg_height = null;
                                $md_width = null;
                                $md_height = null;
                                $sm_width = null;
                                $sm_height = null;
                                if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $val['image_name'])) {
                                    $lg = new Moc10_Image($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $val['image_name']);
                                    $lg_width = $lg->width;
                                    $lg_height = $lg->height;
                                }
                                if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $val['image_name'])) {
                                    $md = new Moc10_Image($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $val['image_name']);
                                    $md_width = $md->width;
                                    $md_height = $md->height;
                                }
                                if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $val['image_name'])) {
                                    $sm = new Moc10_Image($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $val['image_name']);
                                    $sm_width = $sm->width;
                                    $sm_height = $sm->height;
                                }
                                $tmpl = str_replace('[{image_name}]', $val['image_name'], $tmpl);
                                $tmpl = str_replace('[{image_title}]', $val['image_title'], $tmpl);
                                $tmpl = str_replace('[{image_caption}]', $val['image_caption'], $tmpl);
                                $tmpl = str_replace('[{image_updated}]', (string)Moc10_String::setString($val['image_updated'])->date($date_format . $time_format), $tmpl);
                                $tmpl = str_replace('[{large_width}]', $lg_width, $tmpl);
                                $tmpl = str_replace('[{large_height}]', $lg_height, $tmpl);
                                $tmpl = str_replace('[{medium_width}]', $md_width, $tmpl);
                                $tmpl = str_replace('[{medium_height}]', $md_height, $tmpl);
                                $tmpl = str_replace('[{small_width}]', $sm_width, $tmpl);
                                $tmpl = str_replace('[{small_height}]', $sm_height, $tmpl);
                                $tmpl = str_replace('[{site_domain}]', $site->site_domain, $tmpl);
                                $tmpl = str_replace('[{base_path}]', BASE_PATH, $tmpl);
                                $tmpl = str_replace('[{sys_path}]', SYS_PATH, $tmpl);
                                $tmpl = str_replace('[{content_path}]', CONTENT_PATH, $tmpl);
                                $tmpl = str_replace('[{count}]', $item_count, $tmpl);
                                $section_format .= $tmpl;
                            }
                        }

                        // If events found, format and set in content.
                        if (isset($events->rows[0])) {
                            $section_count++;
                            if ($time_format == '') {
                                $tf = 'g:i A';
                            } else {
                                $tf = $time_format;
                            }
                            $item_count = 0;
                            foreach ($events->rows as $val) {
                                $item_count++;
                                $tmpl = $section->short_template;
                                $tmpl = str_replace('[{event_id}]', $val['event_id'], $tmpl);
                                $tmpl = str_replace('[{event_title}]', $val['event_title'], $tmpl);
                                $tmpl = str_replace('[{event_url}]', '/event/' . $val['event_id'] . Moc10_String::setString($val['event_title'])->slug(), $tmpl);
                                if ($val['event_start_date'] != '0000-00-00') {
                                    $tmpl = str_replace('[{event_start_date}]', Moc10_String::setString($val['event_start_date'])->date($date_format), $tmpl);
                                } else {
                                    $rec = Moc10_String::setString($val['event_recurrence'])->split('+');
                                    $event_start_date = $rec[0] . ' ' . $rec[1] . ' of the Month';
                                    $tmpl = str_replace('[{event_start_date}]', $event_start_date, $tmpl);
                                }
                                $tmpl = str_replace('[{event_end_date}]', (($val['event_end_date'] != '0000-00-00') ? ' - ' . Moc10_String::setString($val['event_end_date'])->date($date_format) : null), $tmpl);
                                $tmpl = str_replace('[{event_start_time}]', Moc10_String::setString($val['event_start_time'])->date($tf), $tmpl);
                                $tmpl = str_replace('[{event_end_time}]', (($val['event_end_time'] != '00:00:00') ? ' - ' . Moc10_String::setString($val['event_end_time'])->date($tf) : null), $tmpl);
                                $tmpl = str_replace('[{address1}]', $val['address1'], $tmpl);
                                $tmpl = str_replace('[{address2}]', $val['address2'], $tmpl);
                                $tmpl = str_replace('[{city}]', $val['city'], $tmpl);
                                if (($val['state'] != '--') && ($val['state'] != '')) {
                                    $tmpl = str_replace('[{state}]', $val['state'], $tmpl);
                                } else {
                                    $tmpl = str_replace('[{state}]', '', $tmpl);
                                }
                                $tmpl = str_replace('[{zip}]', $val['zip'], $tmpl);
                                if ($val['country'] != '--') {
                                    $tmpl = str_replace('[{country}]', $val['country'], $tmpl);
                                } else {
                                    $tmpl = str_replace('[{country}]', '', $tmpl);
                                }
                                $tmpl = str_replace('[{phone}]', $val['phone'], $tmpl);
                                $tmpl = str_replace('[{event_link}]', $val['event_link'], $tmpl);
                                $tmpl = str_replace('[{event_desc}]', $val['event_desc'], $tmpl);
                                $tmpl = str_replace('[{count}]', $item_count, $tmpl);
                                $section_format .= $tmpl;
                            }

                        }

                        $section_format .= ($section->short_template_container != 'None') ? str_replace("<", "</", $section->short_template_container) . "\n" : '';
                        $section_format = str_replace('[{section_url}]', BASE_PATH . $section->section_url, $section_format);
                        $section_format = str_replace('[{section_title}]', $section->section_title, $section_format);

                        // Detect any child sections of this section.
                        $childOrderAry = explode('|', $section->sort_order);
                        if ($childOrderAry[0] == 'Title') {
                            $childOrder = 'section_title ' . (($childOrderAry[1] != 'RAND()') ? substr($childOrderAry[1], 0, strpos($childOrderAry[1], ' ')) : 'ASC');
                        } else if (($childOrderAry[0] == 'ID') || ($childOrderAry[0] == 'Date')) {
                            $childOrder = 'section_id ' . (($childOrderAry[1] != 'RAND()') ? substr($childOrderAry[1], 0, strpos($childOrderAry[1], ' ')) : 'ASC');
                        }
                        $childSections = new Phire_Table_Sections();
                        $childSections->findAll($childOrder, 'parent_section_id', $section->section_id);

                        if (isset($childSections->rows[0])) {

                            $isChild = false;
                            foreach($childSections->rows as $child) {
                                if ($child->section_id != $section->section_id) {
                                    $section_format .= "[{section_{$child->section_id}}]\n";
                                    $isChild = true;
                                }
                            }
                            if ($isChild) {
                                $section_format = Phire_Parser_Section::init($section_format, $this->_url)->getContent();
                                $section_count++;
                            }
                        }

                        if ($section_count == 0) {
                            $this->setContent($value, "<div id=\"sectionShort{$sid}\">\n    <p>" . $lang->__('There is currently no content in this section.') . "</p>\n</div>\n");
                        } else {
                            $this->setContent($value, $section_format);
                        }

                    } catch (Exception $e) {
                        $this->setContent($value, '');
                    }

                } else {
                    $this->setContent($value, '');
                }

            }

        }

    }

}
