<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Table
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Table_Pages
 *
 * @category   Phire
 * @package    Phire_Table
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Table_Pages extends Moc10_Record
{

    /**
     * Table name of the database table
     * @var string
     */
    protected $_tableName = 'pages';

    /**
     * Primary ID field name of the database table
     * @var string
     */
    protected $_primaryId = 'page_id';

    /**
     * Constructor
     *
     * Instantiate the database record object.
     *
     * @param array  $fields
     * @param string $type
     * @param string $dbase
     * @param string $host
     * @param string $user
     * @param string $pass
     * @throws Exception
     * @return void
     */
    public function __construct($fields = null, $type = null, $db = null, $host = null, $user = null, $pass = null)
    {

        if (!isset($this->_tableName)) {
            throw new Exception('Error: Table name not set.');
        } else {
            $this->_tableName = DB_PREFIX . $this->_tableName;
            parent::__construct($fields, $type, $db, $host, $user, $pass);
        }

    }

    /**
     * Get the page
     *
     * @param  int|string $id
     * @param  int|string $sid
     * @return void
     */
    public function getPage($id, $sid = null)
    {

        $db_prefix = DB_PREFIX;

        $sql_start = <<<SQLSELECT
SELECT

 {$db_prefix}pages.page_id,
 {$db_prefix}pages.site_id,
 {$db_prefix}pages.user_id,
 {$db_prefix}pages.section_id,
 {$db_prefix}pages.template_id,
 {$db_prefix}pages.page_url,
 {$db_prefix}pages.page_charset,
 {$db_prefix}pages.page_title,
 {$db_prefix}pages.page_author,
 {$db_prefix}pages.page_keywords,
 {$db_prefix}pages.page_desc,
 {$db_prefix}pages.page_robots,
 {$db_prefix}pages.page_content,
 {$db_prefix}pages.page_filter,
 {$db_prefix}pages.page_tags,
 {$db_prefix}pages.page_access,
 {$db_prefix}pages.page_requests,
 {$db_prefix}pages.comments_allowed,
 {$db_prefix}pages.force_ssl_connection,
 {$db_prefix}pages.published,
 {$db_prefix}pages.created,
 {$db_prefix}pages.updated,
 {$db_prefix}pages.expire,
 {$db_prefix}sites.site_domain,
 {$db_prefix}sites.site_docroot,
 {$db_prefix}sites.site_email,
 {$db_prefix}sites.default_type_id,
 {$db_prefix}sites.default_charset,
 {$db_prefix}sites.default_title,
 {$db_prefix}sites.default_author,
 {$db_prefix}sites.default_keywords,
 {$db_prefix}sites.default_desc,
 {$db_prefix}sites.default_robots,
 {$db_prefix}sites.default_template_id,
 {$db_prefix}sites.default_404,
 {$db_prefix}sites.default_date_format,
 {$db_prefix}sites.default_time_format,
 {$db_prefix}sites.comment_allow,
 {$db_prefix}sites.anon_comments,
 {$db_prefix}sites.comment_approval,
 {$db_prefix}sites.member_allow,
 {$db_prefix}sites.member_enable_login,
 {$db_prefix}sites.member_enable_registration,
 {$db_prefix}sites.member_registration,
 {$db_prefix}sites.member_redirects,
 {$db_prefix}sites.spam_rules,
 {$db_prefix}sites.input_captcha,
 {$db_prefix}sites.title_separator,
 {$db_prefix}sites.page_caching,
 {$db_prefix}sites.site_pagination_limit,
 {$db_prefix}sites.site_pagination_range,
 {$db_prefix}sites.use_ssl_connection,
 {$db_prefix}sites.site_live,
 {$db_prefix}templates.template,
 {$db_prefix}templates.mobile_template,
 {$db_prefix}content_types.type,
 {$db_prefix}charsets.charset,
 {$db_prefix}robots.robots

 FROM {$db_prefix}pages

 LEFT JOIN {$db_prefix}sites ON {$db_prefix}pages.site_id = {$db_prefix}sites.site_id
 LEFT JOIN {$db_prefix}templates ON {$db_prefix}pages.template_id = {$db_prefix}templates.template_id
 LEFT JOIN {$db_prefix}content_types ON {$db_prefix}templates.type_id = {$db_prefix}content_types.type_id
 LEFT JOIN {$db_prefix}charsets ON {$db_prefix}pages.page_charset = {$db_prefix}charsets.charset_id
 LEFT JOIN {$db_prefix}robots ON {$db_prefix}pages.page_robots = {$db_prefix}robots.robot_id

SQLSELECT;

        $sql_attempt1 = $sql_start;
        $sql_attempt2 = $sql_start;

        // If numeric ID passed, get page by ID.
        if (is_numeric($id)) {
            $sql_attempt1 .= " WHERE page_id = '" . $id . "'";
            $sql_attempt2 .= " WHERE page_id = '" . $id . "'";
        // Else, if string passed, get page by URL, accounting for the trailing slash.
        } else {
            $alt_id = (substr($id, -1) == '/') ? substr($id, 0, -1) : $id . '/';
            $sql_attempt1 .= " WHERE page_url = '" . $id . "'";
            $sql_attempt2 .= " WHERE page_url = '" . $alt_id . "'";
        }

        // If site ID passed, stipulate the site.
        if (!is_null($sid)) {
            $sql_attempt1 .= " AND {$db_prefix}pages.site_id = '" . $sid . "'";
            $sql_attempt2 .= " AND {$db_prefix}pages.site_id = '" . $sid . "'";
        }

        $sql_attempt1 .= " LIMIT 1";
        $sql_attempt2 .= " LIMIT 1";

        $this->execute($sql_attempt1);

        if (isset($this->rows[0])) {
            $this->_fields = $this->rows[0];
        } else {
            $this->execute($sql_attempt2);
            $this->_fields = (isset($this->rows[0])) ? $this->rows[0] : null;
        }

    }

}
