<?php

/**
 * Phire Add Images
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

set_time_limit(0);
require_once '../../bootstrap.php';

try {

    // Retrieve session and check if the add image action has been cancelled, clearing out any related session data.
    $sess = Moc10_Session::getInstance();
    if ((isset($_GET['action'])) && ($_GET['action'] == 'cancel')) {

        unset($sess->image_error);
        unset($sess->zip_error);
        unset($sess->add_images_form);

        if (isset($_GET['plugin'])) {
            header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_GET['plugin'] . '/?sys_path=' . BASE_PATH . SYS_PATH);
        } else {
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_GET['mobile'])) ? 'mobile/' : '') . 'assets/images.php');
        }

    // Else, get the POST data and validate the form.
    } else {

        unset($sess->add_images_form);
        unset($sess->image_error);
        unset($sess->zip_error);

        $img_nme = (isset($_FILES['image_name_1']['name']) ? $_FILES['image_name_1']['name'] : null);

        $form = new Phire_Form_AddImage(BASE_PATH . SYS_PATH . '/core/process/add.images.php', 'post', '        ');
        $form->init($_POST, $img_nme);

        // If the form is valid, process the new image(s).
        if ($form->isValid()) {

            // Get the image extensions and types.
            $keys = array();
            $exts = array();
            foreach ($_FILES as $key => $value) {
                if ((strpos($key, 'image_name_') !== false) && ($_FILES[$key]['name'] != '')) {
                    $keys[] = substr($key, (strrpos($key, '_') + 1));
                    $path_parts = pathinfo($_FILES[$key]['name']);
                    $exts[] = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                }
            }

            // Check the site for any image format restrictions.
            $site = new Phire_Table_Sites();
            $site->findById($_POST['site_id']);

            $allowed_types = array();
            $allowed_types = explode('|', $site->allowed_image_formats);
            foreach ($exts as $value) {
                if (!in_array(strtolower($value), $allowed_types)) {
                    $msg = ($value == 'NO_EXT') ? $lang->__('That image format is not allowed.') : $lang->__('The %1 image format is not allowed.', strtoupper($value));
                    $sess->image_error = "<div class=\"error\">{$msg}</div>\n";
                }
            }

            // If a image is passed that isn't allowed, return with the error.
            if (isset($sess->image_error)) {

                $sess->add_images_form = $form;
                header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/add-images.php');

            // Else, finish processing the image(s).
            } else {

                // Check the file and image sizes against the max allowed file and image sizes.
                $file_max_size = null;
                $image_max_size = null;

                if (strpos($site->file_max_size, 'MB') !== false) {
                    $file_max_size = str_replace(' MB', '000000', $site->file_max_size);
                } else {
                    $file_max_size = str_replace(' KB', '000', $site->file_max_size);
                }

                if (strpos($site->image_max_size, 'MB') !== false) {
                    $image_max_size = str_replace(' MB', '000000', $site->image_max_size);
                } else {
                    $image_max_size = str_replace(' KB', '000', $site->image_max_size);
                }

                try {

                    // Process batch image upload.
                    if ($_FILES['image_batch_upload']['name'] != '') {

                        // Extract the ZIP file.
                        $zipfile = new Moc10_File_Upload($_FILES['image_batch_upload']['tmp_name'], $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/' . $_FILES['image_batch_upload']['name'], $file_max_size);
                        $zip = new ZipArchive();
                        if ($zip->open($zipfile->fullpath) === true) {
                            $zip->extractTo($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/');
                            $zip->close();
                            $zipfile->delete();
                        }

                        $tempDir = new Moc10_File_Dir($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/');

                        // Evaluate and validate each of the image files.
                        foreach ($tempDir->files as $value) {
                            $path_parts = pathinfo($value);
                            $ext = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                            if (!is_dir($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/' . $value)) {
                                if (!in_array(strtolower($ext), $allowed_types)) {
                                    $msg = ($value == 'NO_EXT') ? $lang->__('That image format is not allowed.') : $lang->__('The %1 image format is not allowed.', strtoupper($ext));
                                    $sess->zip_error = "<div class=\"error\">{$msg}</div>\n";
                                }
                            }
                        }

                        // If an error occurs, delete the uploaded image files.
                        if (isset($sess->zip_error)) {
                            foreach ($tempDir->files as $value) {
                                if (!is_dir($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/' . $value)) {
                                    if (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/' . $value)) {
                                        unlink($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/' . $value);
                                    }
                                }
                            }
                        // Else, process the uploaded image files.
                        } else {

                            foreach ($tempDir->files as $value) {
                                if (!is_dir($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/' . $value)) {
                                    // Check for duplicate images and rename accordingly.
                                    $newimage = $value;
                                    $path_parts = pathinfo($newimage);
                                    $orgfile = $path_parts['filename'];
                                    $ext = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                                    $i = 1;

                                    while (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $newimage)) {
                                        $newimage = $orgfile . '_' . $i . '.' . $ext;
                                        $i++;
                                    }

                                    // If a unique image name is confirmed, process the new image processing.
                                    $image = new Moc10_Image($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/' . $value);
                                    $image->move($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $newimage);

                                    // Process the large image.
                                    if ($site->large_action != 'None') {
                                        switch ($site->large_action) {
                                            case 'Crop':
                                                $image->crop($site->large_size);
                                                break;
                                            case 'Resize':
                                                $image->resize($site->large_size);
                                                break;
                                            case 'Scale':
                                                $image->scale(($site->large_size / 100));
                                                break;
                                        }
                                    }

                                    // Process the medium image.
                                    if ($site->medium_action != 'None') {
                                        switch ($site->medium_action) {
                                            case 'Crop':
                                                $image->crop($site->medium_size, 0, 0, null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                                break;
                                            case 'Resize':
                                                $image->resize($site->medium_size, null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                                break;
                                            case 'Scale':
                                                $image->scale(($site->medium_size / 100), null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                                break;
                                        }
                                    }

                                    // Process the small image.
                                    if ($site->small_action != 'None') {
                                        switch ($site->small_action) {
                                            case 'Crop':
                                                $image->crop($site->small_size, 0, 0, null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                                break;
                                            case 'Resize':
                                                $image->resize($site->small_size, null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                                break;
                                            case 'Scale':
                                                $image->scale(($site->small_size / 100), null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                                break;
                                        }
                                    }

                                    $img_title = str_replace('-', ' ', str_replace('_', ' ', substr($newimage, 0, strrpos($newimage, '.'))));

                                    // Add the new image to the system.
                                    $fields = array('site_id' => $_POST['site_id'],
                                                    'user_id' => $sess->user_id,
                                                    'section_id' => $_POST['section_id'],
                                                    'image_name' => $newimage,
                                                    'image_title' => $img_title,
                                                    'image_caption' => $img_title,
                                                    'image_updated' => date('Y-m-d H:i:s'));
                                    $img = new Phire_Table_Images($fields);
                                    $img->save();

                                }

                            }

                        }

                    }

                    // Process normal image upload.
                    foreach ($keys as $value) {

                        // Check for duplicate images and rename accordingly.
                        $newimage = $_FILES['image_name_' . $value]['name'];
                        $path_parts = pathinfo($newimage);
                        $orgfile = $path_parts['filename'];
                        $ext = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                        $i = 1;

                        while (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $newimage)) {
                            $newimage = $orgfile . '_' . $i . '.' . $ext;
                            $i++;
                        }

                        // If a unique image name is confirmed, process the new image upload.
                        $image = new Moc10_Image_Upload($_FILES['image_name_' . $value]['tmp_name'], $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/large/' . $newimage, $image_max_size);

                        // Process the large image.
                        if ($site->large_action != 'None') {
                            switch ($site->large_action) {
                                case 'Crop':
                                    $image->crop($site->large_size);
                                    break;
                                case 'Resize':
                                    $image->resize($site->large_size);
                                    break;
                                case 'Scale':
                                    $image->scale(($site->large_size / 100));
                                    break;
                            }
                        }

                        // Process the medium image.
                        if ($site->medium_action != 'None') {
                            switch ($site->medium_action) {
                                case 'Crop':
                                    $image->crop($site->medium_size, 0, 0, null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                    break;
                                case 'Resize':
                                    $image->resize($site->medium_size, null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                    break;
                                case 'Scale':
                                    $image->scale(($site->medium_size / 100), null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/medium/' . $newimage);
                                    break;
                            }

                        }

                        // Process the small image.
                        if ($site->small_action != 'None') {
                            switch ($site->small_action) {
                                case 'Crop':
                                    $image->crop($site->small_size, 0, 0, null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                    break;
                                case 'Resize':
                                    $image->resize($site->small_size, null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                    break;
                                case 'Scale':
                                    $image->scale(($site->small_size / 100), null, $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/images/small/' . $newimage);
                                    break;
                            }

                        }

                        $img_title = str_replace('-', ' ', str_replace('_', ' ', substr($newimage, 0, strrpos($newimage, '.'))));

                        // Add the new image to the system.
                        $fields = array('site_id' => $_POST['site_id'],
                                        'user_id' => $sess->user_id,
                                        'section_id' => $_POST['section_id'],
                                        'image_name' => $newimage,
                                        'image_title' => (($_POST['image_title_' . $value] != '') ? $_POST['image_title_' . $value] : $img_title),
                                        'image_caption' => (($_POST['image_caption_' . $value] != '') ? $_POST['image_caption_' . $value] : $img_title),
                                        'image_updated' => date('Y-m-d H:i:s'));
                        $img = new Phire_Table_Images($fields);
                        $img->save();

                    }

                    // If there is a ZIP error, set the form and return.
                    if (isset($sess->zip_error)) {
                        $sess->add_images_form = $form;
                        header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/add-images.php');
                    // Else, return to the images page.
                    } else {
                        unset($sess->add_images_form);
                        unset($sess->image_error);
                        unset($sess->zip_error);
                        if ((isset($_POST['plugin'])) && (!is_null($_POST['plugin']))) {
                            header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_POST['plugin'] .'/?action=saved&sys_path=' . BASE_PATH . SYS_PATH);
                        } else {
                            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/images.php?action=saved');
                        }
                    }

                } catch (Exception $e) {

                    $sess->image_error = "<div class=\"error\">" . $e->getMessage() . "</div>\n";
                    $sess->add_images_form = $form;
                    header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/add-images.php');

                }

            }

        // Else, set the form into a session variable and return.
        } else {

            $sess->add_images_form = $form;
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/add-images.php');

        }

    }

// Else throw a exception/error.
} catch (Exception $e) {

    include_once 'init.php';
    include_once '../includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once '../includes/footer.php';

}

?>
